"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const generator_1 = require("./generator");
/**
 * Vue 路由自动生成插件
 * @param options 插件配置选项
 * @returns Vite 插件
 */
function VueAutoRouter(options = {}) {
    const generator = new generator_1.RouteGenerator(options);
    let server;
    let isWatcherEnabled = false;
    /**
     * 处理文件变化
     * @param file 变化的文件路径
     */
    async function handleFileChange(file) {
        if (!file.endsWith('.vue') || !file.includes('/pages/')) {
            return;
        }
        try {
            await generator.generate();
            console.log(`🔄 Routes regenerated due to changes in ${file}`);
            server?.ws.send({
                type: 'custom',
                event: 'vue-auto-router:update',
                data: { file, timestamp: Date.now() }
            });
        }
        catch (error) {
            console.error(`Failed to regenerate routes for ${file}:`, error);
        }
    }
    /**
     * 启用文件监听
     */
    function enableWatcher() {
        if (!server || isWatcherEnabled)
            return;
        server.watcher.on('add', handleFileChange);
        server.watcher.on('unlink', handleFileChange);
        server.watcher.on('change', handleFileChange);
        isWatcherEnabled = true;
    }
    /**
     * 禁用文件监听
     */
    function disableWatcher() {
        if (!server || !isWatcherEnabled)
            return;
        server.watcher.off('add', handleFileChange);
        server.watcher.off('unlink', handleFileChange);
        server.watcher.off('change', handleFileChange);
        isWatcherEnabled = false;
    }
    return {
        name: 'vue-auto-router',
        /**
         * 配置开发服务器
         */
        async configureServer(_server) {
            server = _server;
            try {
                await generator.generate();
                console.log('🚀 Routes generated successfully');
                enableWatcher();
            }
            catch (error) {
                console.error('Failed to configure server:', error);
                throw error;
            }
        },
        /**
         * 构建开始时生成路由
         */
        async buildStart() {
            try {
                await generator.generate();
                console.log('🚀 Routes generated for production build');
            }
            catch (error) {
                console.error('Failed to generate routes during build:', error);
                throw error;
            }
        },
        /**
         * 构建结束时清理
         */
        buildEnd() {
            disableWatcher();
            server = undefined;
        },
        /**
         * 关闭时清理
         */
        closeBundle() {
            disableWatcher();
            server = undefined;
        }
    };
}
// 修改导出方式
module.exports = VueAutoRouter;
module.exports.default = VueAutoRouter;
exports.default = VueAutoRouter;
//# sourceMappingURL=index.js.map